@@ -2,8 +2,8 @@
 from django.conf import settings
 from app_metrics.tasks import redis_metric_task, redis_gauge_task
 
-def metric(slug, num=1, properties=None):
-    redis_metric_task.delay(slug, num, properties)
+def metric(slug, num=1, properties={}):
+    redis_metric_task.delay(slug, num, **properties)
 
 def timing(slug, seconds_taken, **kwargs):
     # No easy way to do this with redis, so this is a no-op
